@@ -194,7 +194,7 @@ class EssClient(AbstractClient):
 
 
     def CreateFlow(self, request):
-        """创建签署流程
+        """通过模板创建签署流程
         适用场景：在标准制式的合同场景中，可通过提前预制好模板文件，每次调用模板文件的id，补充合同内容信息及签署信息生成电子合同。
         注：该接口是通过模板生成合同流程的前置接口，先创建一个不包含签署文件的流程。配合“创建电子文档”接口和“发起流程”接口使用。
 
